#!/bin/bash

usage()
{
   echo "USAGE: `basename ${0}` <product_dir>"
}

product_dir=${1}

if [ -z ${product_dir} ]
then
   echo "ERROR: please specify the product directory"
   usage
   exit 1
fi

package=ups
pkgver=v6_0_2
pkgdotver=`echo ${pkgver} | sed -e 's/_/./g' | sed -e 's/^v//'`

# we don't know anything about ups flavor yet
OS=`uname`
VRS=`uname -r`
MYDIR=${OS}-${VRS}

echo "ups database is ${product_dir}"

blddir=${product_dir}/${package}/${pkgver}/${MYDIR}

mkdir ${blddir}
if [ ! -d ${blddir} ]
then
   echo "ERROR: failed to create ${blddir}"
   exit 1
fi

cd ${blddir}
pwd
tar xf ${product_dir}/${package}/${pkgver}/tar/${package}-${pkgdotver}.tar.bz2
if [ ! -e Makefile ]
then
   echo "ERROR: cannot find ${blddir}/Makefile"
   exit 1
fi

export UPS_DIR=${blddir}
export PRODUCTS=${product_dir}
if [ -z ${UPS_SHELL} ]
then
   export UPS_SHELL=${SHELL}
   echo "setting UPS_SHELL to ${SHELL}"
fi
make all
echo "make all has finished"

cd ${product_dir}/${package}/${pkgver}

# declare 
if [ ${OS} = "Darwin" ]
then
  flvr=`${UPS_DIR}/bin/ups flavor -2`
else
  flvr=`${UPS_DIR}/bin/ups flavor -4`
fi
pkgdir=${product_dir}/${package}/${pkgver}/${flvr}
mv ${blddir} ${pkgdir} || exit 1
export UPS_DIR=${pkgdir}
echo "now declaring ups ${pkgver} in ${product_dir}"
if [ ${OS} = "Darwin" ]
then
  ${UPS_DIR}/bin/ups declare ups ${pkgver} -r ${package}/${pkgver}/${flvr} -2 -m ups.table -C -z ${product_dir} || exit 1
else
  ${UPS_DIR}/bin/ups declare ups ${pkgver} -r ${package}/${pkgver}/${flvr} -4 -m ups.table -C -z ${product_dir} || exit 1
fi
${UPS_DIR}/bin/ups declare ups ${pkgver} -C -c || exit 1

# copy setups and generate setups_layout
cp -p ${UPS_DIR}/${package}/setups ${product_dir}/setups || exit 1
cp -p ${UPS_DIR}/${package}/setup ${product_dir}/setup || exit 1

# using setup instead of setups here
source ${product_dir}/setup || exit 1

test -r ${product_dir}/setups_layout || cat > ${product_dir}/setups_layout <<\EOF
s_setenv UPS_THIS_DB $SETUPS_DIR
s_setenv PROD_DIR_PREFIX $SETUPS_DIR
EOF

# make the distribution tarball here
cd ${product_dir}

tar cjf ${package}-${pkgdotver}-${flvr}.tar.bz2 \
   setups setup setups_layout .upsfiles \
   ${package}/current.chain/${flvr}_ \
   ${package}/${pkgver}.version/${flvr}_ \
   ${package}/${pkgver}/${flvr}  || exit 1

exit 0
